
import {axios} from '@/utils/request'

export function actorList(parameter) {
    return axios({
      url: "/ctop/actor/list",
      method: 'get',
      params: parameter
    })
}


export function getCityList(parameter) {
    return axios({
      url: "/ctop/actor/getCityList",
      method: 'get',
      params: parameter
    })
}

export function getTagList(parameter) {
    return axios({
      url: "/ctop/actor/getTagList",
      method: 'get',
      params: parameter
    })
}

export function propList(parameter) {
    return axios({
      url: "/ctop/prop/list",
      method: 'get',
      params: parameter
    })
}

export function actorPhotoList(parameter) {
    return axios({
      url: "/ctop/actor/photo/list",
      method: 'get',
      params: parameter
    })
}

export function actorPhotoDelete(parameter) {
    return axios({
      url: "/ctop/actor/photo/delete",
      method: 'delete',
      params: parameter
    })
}
export function actorListDelete(parameter) {
    return axios({
      url: "/ctop/actor/delete",
      method: 'delete',
      params: parameter
    })
}
export function propListDelete(parameter) {
    return axios({
      url: "/ctop/prop/delete",
      method: 'delete',
      params: parameter
    })
}

export function actorPhotoAdd(parameter) {
    return axios({
      url: "/ctop/actor/photo/add",
      method: 'post',
      params: parameter
    })
}

export function actorVideoDelete(parameter) {
    return axios({
      url: "/ctop/actor/video/delete",
      method: 'delete',
      params: parameter
    })
}

export function actorVideoAdd(parameter) {
    return axios({
      url: "/ctop/actor/video/add",
      method: 'post',
      params: parameter
    })
}

export function actorDetail(parameter) {
    return axios({
        url: "/ctop/actor/detail",
        method: 'get',
        params: parameter
    })
}
export function propDetail(parameter) {
    return axios({
        url: "/ctop/prop/detail",
        method: 'get',
        params: parameter
    })
}


export function actorCommentList(parameter) {
    return axios({
        url: "/ctop/actor/comment/list",
        method: 'get',
        params: parameter
    })
}

export function actorCommentAdd(parameter) {
    return axios({
        url: "/ctop/actor/comment/add",
        method: 'post',
        params: parameter
    })
}

export function actorCommentDetele(parameter) {
    return axios({
        url: "/ctop/actor/comment/delete",
        method: 'delete',
        params: parameter
    })
}


export function actorVideoList(parameter) {
    return axios({
        url: "/ctop/actor/video/list",
        method: 'get',
        params: parameter
    })
}


export function fileCheck(parameter) {
    return axios({
        url: "/file/check",
        method: 'get',
        params: parameter
    })
}


export function fileCheckImage(parameter) {
    return axios({
        url: "/file/imageCheck",
        method: 'get',
        params: parameter
    })
}

export function fileInsert(parameter) {
    return axios({
        url: "/file/insert",
        method: 'post',
        data: parameter
    })
}

export function fileInsertV2(parameter) {
    return axios({
        url: "/insertV2",
        method: 'post',
        data: parameter
    })
}
export function orderFileInsert(parameter) {
    return axios({
        url: "/platform/file/uploadVideo",
        method: 'post',
        data: parameter
    })
}


export function fileEdit(parameter) {
    return axios({
        url: "/ctop/materialInfo/edit",
        method: 'put',
        data: parameter
    })
}

export function fileEditUpdate(parameter) {
    return axios({
        url: "/ctop/materialInfo/bytedance/edit",
        method: 'put',
        data: parameter
    })
}

export function fileEditUpdateBatch(parameter) {
    return axios({
        url: "/ctop/materialInfo/bytedance/batchedit",
        method: 'put',
        data: parameter
    })
}

export function fileEditAll(parameter) {
    return axios({
        url: "/ctop/materialAscription/update",
        method: 'put',
        data: parameter
    })
}
